#####################################################
#        Epiphytic diatom community structure       #
#       and richness determined by algal host and   #
#         sampling location in the South            #
#           Shetland Islands (Antarctica)           #
#                                                   #
#   A. Burfeid-Castellanos, R. Martín, M. Kloster,  #
#    C. Angulo-Preckler, C. Avila & B. Beszteri     #
#                                                   #
#            Rhodophytes and Phaeophytes            #
#####################################################

#DC2 campaign 2016-2017
#BB1 campaign 2017-2018
#BB2 campaign 2018-2019

#packages
library(vegan)
library(vegetarian)
library(MASS)
library(vegan3d)
library(cluster)

#set directory
#setwd("C:/Users/Andrea/sciebo/Antarctica/Biigle results/Abundances")
setwd("set your directory here")

#Open total abundance data
total<-read.table("Taxa Matrix and Environmental parameters.txt", header = T, row.names = 1,sep = "\t")

Ph<-subset(total, "Phylum.basibiont"== "Phaeo")
Rh<-subset(total, "Phylum.basibiont"== "Rhodo")

RP<-rbind(Ph,Rh)

#subdivision into inventory (data) and environmental (env)
env<-RP[,132:139]
data<-RP[,1:131]

#Non-dimensional scaling, dissimilarities input
vare.dis<-vegdist(data)
vare.mds0 <- isoMDS(vare.dis)
stressplot(vare.mds0, vare.dis)
ordiplot(vare.mds0, type="p")
vare.mds<-metaMDS(data, trace=FALSE)
vare.mds
plot(vare.mds, type="t")

#Community dissimilarities
rankindex(scale(data), data, c("euc", "man", "bray","jac","kul"))
dis<-vegdist(decostand(data,"norm"),"man")
dis2<-vegdist(decostand(data,"hell"), "man")
d<-vegdist(data,"bray", binary = TRUE)
d1<-designdist(data,"(A+B-2*J)/(A+B)")
d2<-designdist(data,"(b+c)/(2*a+b+c)", abcd = TRUE)

#Comparing ordinators
tmp <-wisconsin(sqrt(data))
dis3<-vegdist(tmp)
vare.mds0<-isoMDS(dis3, trace=0)
pro<-procrustes(vare.mds, vare.mds0)
pro
plot(pro)
plot(pro, kind=2)

#Eigenvector methods
vare.pca <- rda(data)
vare.pca
plot(vare.pca)
sum(apply(data,2,var))
biplot(vare.pca, scaling = 1)

#Multivariate study
vare.pca <- rda(data, scale=TRUE)
vare.pca
plot(vare.pca, scaling=3)
dim(data)
vare.ca<-cca(data)
vare.ca
summary(vare.ca)
plot(vare.ca)
chisq.test(data/sum(data))
plot(vare.ca, scaling=1)

#Detrended correspondence analysis
vare.dca <- decorana(data)
vare.dca
plot(vare.dca,display = "sites")

#downweight, also in CCA, reduces influences of rare species
#Ordination graphics
data(BCI)
BCI
mod<-decorana(data)
plot(mod)
names(BCI)[1:5]
shnam<-make.cepnames(names(data))
shnam[1:5]
pl<-plot(mod, dis="sp")
identify(pl,"sp",labels=shnam)
stems<-colSums(data)
plot(mod,dis="sp", type="n")
sel<-orditorp(mod,dis="sp", lab=shnam, priority=stems, pcol = "gray", pch="+")
plot(mod,dis="sp",type="n")
ordilabel(mod,dis="sp", lab=shnam, priority=stems)
sel[1:14]

#Environmental interpretation
ef<-envfit(vare.mds, env, permu=99999)
ef
plot(vare.mds, display = "sites")
vare.mds
plot(ef, p.max=0.1)

#Surface fitting
ef<-envfit(vare.mds~Depth+Phylum.basibiont+Depth.div+Depth.int, env)
plot(vare.mds, display = "sites")
plot(ef)
tmp<-with(env, ordisurf(vare.mds,Depth, add=TRUE))
with(env, ordisurf(vare.mds, Depth.int, add=TRUE, col="green4"))

#Factors
data.ca<-cca(data)
ef<-envfit(data.ca, env, permutations = 99999)
ef
plot(data.ca,display="sites")
plot(ef)

#Model specification
vare.cca<-cca(data~Phylum.basibiont+Depth.int, env)
vare.cca
summary(vare.cca)
plot(vare.cca)

ordiplot3d(vare.cca, type = "h")
data.cca<-cca(data~Phylum.basibiont,env)
plot(data.cca)
data.cca
vare.cca<-cca(data~Depth,env)
plot(vare.cca)

#Permutation tests
anova(vare.cca)
mod<-cca(data~Depth.int+Phylum.basibiont, env)
anova(mod, by="term", step=10000)
anova(mod, by="margin", perm=10000)
anova(mod, by="axis", perm=10000)

#Model building
mod1<-cca(data~.,env)
mod1
plot(procrustes(cca(data), mod1))
#AIC
mod0<- cca(data~1, env)
mod<-step(mod0, scope=formula(mod1), test="perm")
modb<-step(mod1, scope=list(lower=formula(mod0), upper=formula(mod1)), trace=0)
modb
modb$anova
vif.cca(mod1)
vif.cca(mod)
modb
spenvcor(mod)
data.cca<-cca(data~Depth, env)
plot(data.cca, display=c("lc", "wa"), type="p")
ordispider(data.cca, col="blue")

#Biplot arrows and environmental calibration
pred<-calibrate(mod)
head(pred)
with(env, plot(Depth, pred[,"Depth"] ~ Depth, ylab="Prediction Error"))
abline(h=0, col="grey")
plot(mod, display=c("bp", "wa", "lc"))
ef<-with(env, Depth, display="lc", add=TRUE)
ef

#itioned or partial models
data.cca<-cca(data~Depth.int + Phylum.basibiont, env)
plot(data.cca)
data.cca
anova(data.cca, perm.max=10000)
with(env, anova(data.cca, strata=Loc))

#DISSIMILARITIES AND ENVIRONMENT
betad<-betadiver(data, "z")
adonis(betad~Depth, env, perm=10000)
adonis(betad~Depth*Phylum.basibiont, env, perm=10000)
adonis(betad~Campaign*Depth, env, perm=10000)
mod<-with(env, betadisper(betad, Depth))
mod
plot(mod)
boxplot(mod)
anova(mod)
permutest(mod)
TukeyHSD(mod)
mod

#CCA with betadiversity per host
mod<-with(env, betadisper(betad, Phylum.basibiont))
mod
plot(mod)
boxplot(mod)
anova(mod)
permutest(mod)
TukeyHSD(mod)

#CCA with betadiversity per Location
mod<-with(env, betadisper(betad, Loc))
plot(mod)
boxplot(mod)
anova(mod)
permutest(mod)
TukeyHSD(mod)

#MANTEL TEST
names(env)
envo<-env[,4:5]
names(envo)
envo<-as.numeric(envo)
pc<-prcomp(envo, scale=TRUE)
pc<-scores(pc,display="sites", choices = 1:4)
edis<-vegdist(pc, method="euclid")
vare.dis<-vegdist(wisconsin(sqrt(data)))
mantel(vare.dis, edis)
plot(vare.dis, edis)

#Protest Procrustes test
pc<-scores(pc,choices=1:2)
pro<-protest(vare.mds, pc)
plot(pro)
pro


# CLASSIFICATION
#Clustering
dis<-vegdist(data)
clus<-hclust(dis,"average")
plot(clus)
range(dis)
cor(dis, cophenetic(clus))
plot(clus)
rect.hclust(clus, 3)
grp<-cutree(clus,2)
par(mfcol=c(2,3))
boxplot(Depth.int~grp, data=env, notch=FALSE)
boxplot(Depth~grp, data=env, notch=FALSE)


ord<-cca(data)
par(mfcol=c(1,1))
plot(ord, display="sites")
ordihull(ord, grp, lty=2, col="red")
plot(ord, display="sites")
ordicluster(ord,clus,col="blue")
mst<-spantree(dis, toolong=1)
plot(mst, ord=ord, pch=21, col="red", bg="yellow", type="t")

#Classified community tables
wa<-scores(ord, display="sites", choices=1)
den<-as.dendrogram(clus)
oden<-reorder(den, wa, mean)
op<-par(mfrow=c(2,1), mar=c(3,5,1,2)+.1)
plot(den)
plot(oden)
par(op)
vegemite(data, use=oden, zero="-")
